@@ -57,7 +57,9 @@ def codegen(
         else ".".join(list(reversed(sp.netloc.split("."))) + sp.path.strip("/").split("/"))
     )
     info = parser_info or pkg
-    if lang == "python" or lang == "cpp" or lang == "dlang":
+    salad_version = schema_metadata.get("saladVersion", "v1.1")
+
+    if lang in set(["python", "cpp", "dlang"]):
         if target:
             dest: Union[TextIOWrapper, TextIO] = open(target, mode="w", encoding="utf-8")
         else:
@@ -72,7 +74,7 @@ def codegen(
             )
             gen.parse(j)
             return
-        elif lang == "dlang":
+        if lang == "dlang":
             gen = DlangCodeGen(
                 base,
                 dest,
@@ -80,11 +82,13 @@ def codegen(
                 pkg,
                 copyright,
                 info,
+                salad_version,
             )
             gen.parse(j)
             return
-        else:
-            gen = PythonCodeGen(dest, copyright=copyright, parser_info=info)
+        gen = PythonCodeGen(
+            dest, copyright=copyright, parser_info=info, salad_version=salad_version
+        )
 
     elif lang == "java":
         gen = JavaCodeGen(
